[−][src]Module awc::error
Http client errors
Enums
| ConnectError | A set of errors that can occur while connecting to an HTTP host |
| FreezeRequestError | A set of errors that can occur during freezing a request |
| InvalidUrl | |
| JsonPayloadError | A set of errors that can occur during parsing json payloads |
| PayloadError | A set of errors that can occur during payload parsing |
| SendRequestError | A set of errors that can occur during request sending and response reading |
| WsClientError | Websocket client error |
| WsHandshakeError | Websocket handshake errors |
| WsProtocolError | Websocket protocol errors |